#!/bin/tcsh

setenv COB_LIBRARY_PATH .
echo MISC TEST GROUP

rm -f prog.cob
echo Source file not found
cobc -C -x -debug -Wall -std=cobol2002 prog.cob >& comp.out
if ( $? == 0 ) goto err
diff misc.0 comp.out
if ( $? != 0 ) goto err

echo Comma separator without space
cp misc.1 prog.cob
cobc -x -debug -Wall -std=cobol2002 prog.cob >& comp.out
if ( $? != 0 ) goto err
prog > result
if ( $? != 0 ) goto err
diff misc.2 result
if ( $? != 0 ) goto err

echo LOCAL-STORAGE
cp misc.3 callee.cob
cobc -m -debug -Wall -std=cobol2002 callee.cob >& comp.out
if ( $? != 0 ) goto err
cp misc.4 caller.cob
cobc -x -debug -Wall -std=cobol2002 -o prog caller.cob >& comp.out
if ( $? != 0 ) goto err
prog > result
if ( $? != 0 ) goto err
diff misc.5 result
if ( $? != 0 ) goto err

echo EXTERNAL data item
cp misc.6 callee.cob
cobc -m -debug -Wall -std=cobol2002 callee.cob >& comp.out
if ( $? != 0 ) goto err
cp misc.7 caller.cob
cobc -x -debug -Wall -std=cobol2002 -o prog caller.cob >& comp.out
if ( $? != 0 ) goto err
prog > result
if ( $? != 0 ) goto err
diff misc.8 result
if ( $? != 0 ) goto err

echo EXTERNAL AS data item
cp misc.9 callee.cob
cobc -m -debug -Wall -std=cobol2002 callee.cob >& comp.out
if ( $? != 0 ) goto err
cp misc.10 caller.cob
cobc -x -debug -Wall -std=cobol2002 -o prog caller.cob >& comp.out
if ( $? != 0 ) goto err
prog > result
if ( $? != 0 ) goto err
diff misc.11 result
if ( $? != 0 ) goto err

echo cobcrun validation
cp misc.12 callee.cob
cobc -m -debug -Wall -std=cobol2002 callee.cob >& comp.out
if ( $? != 0 ) goto err
cp misc.13 caller.cob
cobc -m -debug -Wall -std=cobol2002 caller.cob >& comp.out
if ( $? != 0 ) goto err
cobcrun caller > result
if ( $? != 0 ) goto err
diff misc.14 result
if ( $? != 0 ) goto err

echo MOVE to itself
cp misc.15 prog.cob
cobc -x -debug -Wall -std=cobol2002 prog.cob >& comp.out
if ( $? != 0 ) goto err
prog > result
if ( $? != 0 ) goto err
diff misc.16 result
if ( $? != 0 ) goto err

echo MOVE with refmod
cp misc.17 prog.cob
cobc -x -debug -Wall -std=cobol2002 prog.cob >& comp.out
if ( $? != 0 ) goto err
prog > result
if ( $? != 0 ) goto err
diff misc.18 result
if ( $? != 0 ) goto err

echo MOVE with refmod \(variable\)
cp misc.19 prog.cob
cobc -x -debug -Wall -std=cobol2002 prog.cob >& comp.out
if ( $? != 0 ) goto err
prog > result
if ( $? != 0 ) goto err
diff misc.20 result
if ( $? != 0 ) goto err

echo MOVE with group refmod
cp misc.21 prog.cob
cobc -x -debug -Wall -std=cobol2002 prog.cob >& comp.out
if ( $? != 0 ) goto err
prog > result
if ( $? != 0 ) goto err
diff misc.22 result
if ( $? != 0 ) goto err

echo MOVE indexes
cp misc.23 prog.cob
cobc -x -debug -Wall -std=cobol2002 prog.cob >& comp.out
if ( $? != 0 ) goto err
prog > result
if ( $? != 0 ) goto err
diff misc.24 result
if ( $? != 0 ) goto err

echo MOVE X\'00\'
cp misc.25 dump.c
c89 -Wc,dll,xplink,expo -Wl,dll,xplink -o dump.so dump.c >& comp.out
if ( $? != 0 ) goto err
cp misc.26 prog.cob
cobc -x -debug -Wall -std=cobol2002 prog.cob >& comp.out
if ( $? != 0 ) goto err
prog > result
if ( $? != 0 ) goto err
diff misc.27 result
if ( $? != 0 ) goto err

echo Level 01 subscripts
cp misc.28 prog.cob
cobc -x -debug -Wall -std=cobol2002 prog.cob >& comp.out
if ( $? == 0 ) goto err
diff misc.29 comp.out
if ( $? != 0 ) goto err

echo Class check with reference modification
cp misc.30 prog.cob
cobc -x -debug -Wall -std=cobol2002 prog.cob >& comp.out
if ( $? != 0 ) goto err
prog > result
if ( $? != 0 ) goto err
diff misc.31 result
if ( $? != 0 ) goto err

echo Index and parenthesized expression
cp misc.32 prog.cob
cobc -x -debug -Wall -std=cobol2002 prog.cob >& comp.out
if ( $? != 0 ) goto err

echo Alphanumeric and binary numeric
cp misc.33 prog.cob
cobc -x -debug -Wall -std=cobol2002 prog.cob >& comp.out
if ( $? != 0 ) goto err
prog > result
if ( $? != 0 ) goto err
diff misc.34 result
if ( $? != 0 ) goto err

echo Dynamic call with static linking
cp misc.35 callee.cob
cobc -c -m -debug -Wall -std=cobol2002 callee.cob >& comp.out
if ( $? != 0 ) goto err
cp misc.36 caller.cob
cobc -c -x -debug -Wall -std=cobol2002 caller.cob >& comp.out
if ( $? != 0 ) goto err
cobc -x -o prog caller.o callee.o >& comp.out
if ( $? != 0 ) goto err
prog > result
if ( $? != 0 ) goto err
diff misc.37 result
if ( $? != 0 ) goto err

echo CALL m1. CALL m2. CALL m1.
cp misc.38 m1.cob
cobc -m -debug -Wall -std=cobol2002 m1.cob >& comp.out
if ( $? != 0 ) goto err
cp misc.39 m2.cob
cobc -m -debug -Wall -std=cobol2002 m2.cob >& comp.out
if ( $? != 0 ) goto err
cp misc.40 caller.cob
cobc -x -debug -Wall -std=cobol2002 caller.cob >& comp.out
if ( $? != 0 ) goto err
caller > result
if ( $? != 0 ) goto err
diff misc.41 result
if ( $? != 0 ) goto err

echo CALL: binary literal parameter/LENGTH OF
cp misc.42 test.conf
cp misc.43 dump.c
cp misc.44 prog.cob
cobc -m -debug -Wall -std=cobol2002 dump.c >& comp.out
if ( $? != 0 ) goto err
cobc -x -debug -Wall -std=cobol2002 prog.cob >& comp.out
if ( $? != 0 ) goto err
prog > result
if ( $? != 0 ) goto err
diff misc.45 result
if ( $? != 0 ) goto err
cobc -x -debug -Wall -conf=test.conf prog.cob >& comp.out
if ( $? != 0 ) goto err
prog > result
if ( $? != 0 ) goto err
diff misc.45 result
if ( $? != 0 ) goto err

echo INSPECT REPLACING LEADING ZEROS BY SPACES
cp misc.46 prog.cob
cobc -x -debug -Wall -std=cobol2002 prog.cob >& comp.out
if ( $? != 0 ) goto err
prog > result
if ( $? != 0 ) goto err
diff misc.47 result
if ( $? != 0 ) goto err

echo INSPECT: no repeat conversion check
cp misc.48 prog.cob
cobc -x -debug -Wall -std=cobol2002 prog.cob >& comp.out
if ( $? != 0 ) goto err
prog > result
if ( $? != 0 ) goto err
diff misc.49 result
if ( $? != 0 ) goto err

echo INSPECT: TALLYING BEFORE
cp misc.50 prog.cob
cobc -x -debug -Wall -std=cobol2002 prog.cob >& comp.out
if ( $? != 0 ) goto err
prog > result
if ( $? != 0 ) goto err
diff misc.51 result
if ( $? != 0 ) goto err

echo INSPECT: TALLYING AFTER
cp misc.52 prog.cob
cobc -x -debug -Wall -std=cobol2002 prog.cob >& comp.out
if ( $? != 0 ) goto err
prog > result
if ( $? != 0 ) goto err
diff misc.53 result
if ( $? != 0 ) goto err

echo INSPECT REPLACING TRAILING ZEROS BY SPACES
cp misc.54 prog.cob
cobc -x -debug -Wall -std=cobol2002 prog.cob >& comp.out
if ( $? != 0 ) goto err
prog > result
if ( $? != 0 ) goto err
diff misc.55 result
if ( $? != 0 ) goto err

echo INSPECT REPLACING complex
cp misc.101 prog.cob
cobc -x -debug -Wall -std=cobol2002 prog.cob >& comp.out
if ( $? != 0 ) goto err
prog > result
if ( $? != 0 ) goto err
diff misc.102 result
if ( $? != 0 ) goto err

echo SWITCHES
setenv COB_SWITCH_1 ON
setenv COB_SWITCH_2 OFF
cp misc.56 prog.cob
cobc -x -debug -Wall -std=cobol2002 prog.cob >& comp.out
if ( $? != 0 ) goto err
prog > result
if ( $? != 0 ) goto err
diff misc.57 result
if ( $? != 0 ) goto err
unsetenv COB_SWITCH_1
unsetenv COB_SWITCH_2

echo Nested PERFORM
cp misc.58 prog.cob
cobc -x -debug -Wall -std=cobol2002 prog.cob >& comp.out
if ( $? != 0 ) goto err
prog > result
if ( $? != 0 ) goto err
diff misc.59 result
if ( $? != 0 ) goto err

echo EXIT PERFORM
cp misc.60 prog.cob
cobc -x -debug -Wall -std=cobol2002 prog.cob >& comp.out
if ( $? != 0 ) goto err
prog > result
if ( $? != 0 ) goto err
diff misc.61 result
if ( $? != 0 ) goto err

echo EXIT PERFORM CYCLE
cp misc.62 prog.cob
cobc -x -debug -Wall -std=cobol2002 prog.cob >& comp.out
if ( $? != 0 ) goto err
prog > result
if ( $? != 0 ) goto err
diff misc.63 result
if ( $? != 0 ) goto err

echo 88 with FILLER
cp misc.64 prog.cob
cobc -x -debug -Wall -std=cobol2002 prog.cob >& comp.out
if ( $? != 0 ) goto err
prog > result
if ( $? != 0 ) goto err
diff misc.65 result
if ( $? != 0 ) goto err

echo non-overflow after overflow
cp misc.66 prog.cob
cobc -x -debug -Wall -std=cobol2002 prog.cob >& comp.out
if ( $? != 0 ) goto err
prog > result
if ( $? != 0 ) goto err
diff misc.67 result
if ( $? != 0 ) goto err

echo PERFORM ... CONTINUE
cp misc.68 prog.cob
cobc -x -debug -Wall -std=cobol2002 prog.cob >& comp.out
if ( $? != 0 ) goto err

echo STRING with subscript reference
cp misc.69 prog.cob
cobc -x -debug -Wall -std=cobol2002 prog.cob >& comp.out
if ( $? != 0 ) goto err
prog > result
if ( $? != 0 ) goto err
diff misc.70 result
if ( $? != 0 ) goto err

echo UNSTRING DELIMITED ALL LOW-VALUE
cp misc.71 prog.cob
cobc -x -debug -Wall -std=cobol2002 prog.cob >& comp.out
if ( $? != 0 ) goto err
prog > result
if ( $? != 0 ) goto err
diff misc.72 result
if ( $? != 0 ) goto err

echo READ INTO AT-END sequence
cp misc.73 prog.cob
cobc -x -debug -Wall -std=cobol2002 prog.cob >& comp.out
if ( $? != 0 ) goto err
prog > result
if ( $? != 0 ) goto err
diff misc.74 result
if ( $? != 0 ) goto err

echo First READ on empty SEQUENTIAL INDEXED file
cp misc.75 prog.cob
cobc -x -debug -Wall -std=cobol2002 prog.cob >& comp.out
if ( $? != 0 ) goto err
prog > result
if ( $? != 0 ) goto err
diff misc.76 result
if ( $? != 0 ) goto err

echo REWRITE a RELATIVE file with RANDOM access
cp misc.77 prog.cob
cobc -x -debug -Wall -std=cobol2002 prog.cob >& comp.out
if ( $? != 0 ) goto err
prog > result
if ( $? != 0 ) goto err
diff misc.78 result
if ( $? != 0 ) goto err

echo SORT: table sort
cp misc.79 prog.cob
cobc -x -debug -Wall -std=cobol2002 prog.cob >& comp.out
if ( $? != 0 ) goto err
prog > result
if ( $? != 0 ) goto err
diff misc.80 result
if ( $? != 0 ) goto err

echo SORT: EBCDIC table sort
cp misc.81 prog.cob
cobc -x -debug -Wall -std=cobol2002 prog.cob >& comp.out
if ( $? != 0 ) goto err
prog > result
if ( $? != 0 ) goto err
diff misc.82 result
if ( $? != 0 ) goto err

echo SORT nonexistent file
cp misc.83 prog.cob
cobc -x -debug -Wall -std=cobol2002 prog.cob >& comp.out
if ( $? != 0 ) goto err
prog > result
if ( $? != 0 ) goto err
if ( ! -f SORT-OUT ) goto err
rm SORT-OUT

echo PIC ZZZ-, ZZZ+
cp misc.84 prog.cob
cobc -x -debug -Wall -std=cobol2002 prog.cob >& comp.out
if ( $? != 0 ) goto err
prog > result
if ( $? != 0 ) goto err
diff misc.85 result
if ( $? != 0 ) goto err

echo Larger REDEFINES lengths
cp misc.86 prog.cob
cobc -C -x -debug -Wall -std=mf prog.cob >& comp.out
if ( $? != 0 ) goto err
diff misc.87 comp.out
if ( $? != 0 ) goto err
cobc -x -debug -Wall -std=mf prog.c >& comp.out
if ( $? != 0 ) goto err
prog > result
if ( $? != 0 ) goto err
diff misc.88 result
if ( $? != 0 ) goto err

echo PERFORM type OSVS
cp misc.89 test.conf
cp misc.90 prog.cob
cobc -x -debug -Wall -conf=test.conf prog.cob >& comp.out
if ( $? != 0 ) goto err
prog > result
if ( $? != 0 ) goto err
diff misc.91 result
if ( $? != 0 ) goto err

echo Sticky LINKAGE
cp misc.92 test.conf
cp misc.93 callee.cob
cp misc.94 caller.cob
cobc -m -debug -Wall -conf=test.conf callee.cob >& comp.out
if ( $? != 0 ) goto err
cobc -x -debug -Wall -conf=test.conf caller.cob >& comp.out
if ( $? != 0 ) goto err
caller > result
if ( $? != 0 ) goto err
diff misc.95 result
if ( $? != 0 ) goto err

echo COB_PRE_LOAD
cp misc.96 callee.cob
cp misc.97 caller.cob
cobc -m -debug -Wall -std=cobol2002 callee.cob >& comp.out
if ( $? != 0 ) goto err
cobc -x -debug -Wall -std=cobol2002 caller.cob >& comp.out
if ( $? != 0 ) goto err
setenv COB_PRE_LOAD callee
caller > result
if ( $? != 0 ) goto err
diff misc.98 result
if ( $? != 0 ) goto err

echo 88 level with FALSE IS clause
cp misc.99 prog.cob
cobc -x -debug -Wall -std=cobol2002 prog.cob >& comp.out
if ( $? != 0 ) goto err
prog > result
if ( $? != 0 ) goto err
diff misc.100 result
if ( $? != 0 ) goto err

echo ALLOCATE/FREE with BASED item
cp misc.103 prog.cob
cobc -x -debug -Wall -std=cobol2002 prog.cob >& comp.out
if ( $? != 0 ) goto err
prog > result
if ( $? != 0 ) goto err
diff misc.104 result
if ( $? != 0 ) goto err

echo CALL with OMITTED parameter
cp misc.105 callee.cob
cp misc.106 caller.cob
cobc -m -debug -Wall -std=cobol2002 callee.cob >& comp.out
if ( $? != 0 ) goto err
cobc -x -debug -Wall -std=cobol2002 caller.cob >& comp.out
if ( $? != 0 ) goto err
caller > result
if ( $? != 0 ) goto err
diff misc.107 result
if ( $? != 0 ) goto err

echo MISC TEST PASSED
rm test.conf m1.* m2.* TEST-FILE dump.* caller* callee* prog* result comp.out
goto end

err:
	echo MISC TEST FAILED
	exit(1)
end:
	exit(0)

